<?php
/**
 * Real Home Theme Customizer Property Post Fields
 *
 * @package Real_Home
 */

class Real_Home_Customize_Property_Post_Fields extends Real_Home_Customize_Base_Field {

	/**
	 * Arguments for fields.
	 *
	 * @return void
	 */
	public function init() {
		// Page Header
		$this->args = array(
			// Post Header
			'real_home_property_single_post_header_elements' => array(
				'type'              => 'sortable',
				'default'           => array( 'post-title', 'breadcrumb' ),
				'sanitize_callback' => array( 'Real_Home_Customizer_Sanitize_Callback', 'sanitize_sortable' ),
				'label'             => esc_html__( 'Sort Elements', 'real-home' ),
				'description'       => esc_html__( 'Enable Social Share elements and sort list by drag and drop.', 'real-home' ),
				'section'           => 'real_home_property_single_post_header_section',
				'priority'          => 15,
				'choices'           => array(
					'post-title' => esc_html__( 'Post Title', 'real-home' ),
					'post-meta'  => esc_html__( 'Post Meta', 'real-home' ),
					'breadcrumb' => esc_html__( 'Breadcrumb', 'real-home' ),
				),
			),
			// Meta Elements
			'real_home_property_single_post_meta_elements' => array(
				'type'              => 'sortable',
				'default'           => array( 'author', 'post-date' ),
				'sanitize_callback' => array( 'Real_Home_Customizer_Sanitize_Callback', 'sanitize_sortable' ),
				'label'             => esc_html__( 'Post Meta Elements', 'real-home' ),
				'description'       => esc_html__( 'Enable Post Meta Elements and sort their order by drag and drop.', 'real-home' ),
				'section'           => 'real_home_property_single_post_header_section',
				'priority'          => 15,
				'choices'           => array(
					'author'    => esc_html__( 'Author', 'real-home' ),
					'comments'  => esc_html__( 'Comments', 'real-home' ),
					'post-date' => esc_html__( 'Post Date', 'real-home' ),
					'location'  => esc_html__( 'Property Location', 'real-home' ),
					'status'    => esc_html__( 'Property Status', 'real-home' ),
					'types'     => esc_html__( 'Property Type', 'real-home' ),

				),
			),
		);
		// Post Content
		$this->args = array_merge(
			$this->args,
			array(
				'real_home_property_post_elements' => array(
					'type'              => 'sortable',
					'default'           => array( 'address', 'main', 'other', 'gallery', 'features', 'floor', 'video', 'author' ),
					'sanitize_callback' => array( 'Real_Home_Customizer_Sanitize_Callback', 'sanitize_sortable' ),
					'label'             => esc_html__( 'Sort Elements', 'real-home' ),
					'description'       => esc_html__( 'To reorder elements drag and drop them.', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
					'choices'           => array(
						'address'  => esc_html__( 'Address', 'real-home' ),
						'main'     => esc_html__( 'Main Detail', 'real-home' ),
						'other'    => esc_html__( 'Other Detail', 'real-home' ),
						'gallery'  => esc_html__( 'Gallery', 'real-home' ),
						'features' => esc_html__( 'Features', 'real-home' ),
						'floor'    => esc_html__( 'Floor Plan', 'real-home' ),
						'video'    => esc_html__( 'Video', 'real-home' ),
						'author'   => esc_html__( 'Author Box', 'real-home' ),
					),
				),
				// Address Heading
				'real_home_property_post_element_address' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Address', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Address Heading', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
				),
				// Main Heading
				'real_home_property_post_element_main' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Main Detail', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Main Heading', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
				),
				// Other Heading
				'real_home_property_post_element_other' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Others Detail', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Other Heading', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
				),
				// Gallery Heading
				'real_home_property_post_element_gallery' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Gallery', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Gallery Heading', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
				),
				// Features Heading
				'real_home_property_post_element_features' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Features', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Features Heading', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
				),
				// Floor Plan Heading
				'real_home_property_post_element_floor' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Floor Plan', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Floor Heading', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
				),
				// Video Heading
				'real_home_property_post_element_video' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Video', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Video Heading', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
				),
				// Author Heading
				'real_home_property_post_element_author' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Author Box', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Author Heading', 'real-home' ),
					'section'           => 'real_home_property_single_post_content_section',
					'priority'          => 5,
				),
			)
		);
		
		// Related Posts
		$this->args = array_merge(
			$this->args,
			array(
				// Author Heading
				'real_home_property_related_posts_heading' => array(
					'type'              => 'text',
					'default'           => esc_html__( 'Feature Listings', 'real-home' ),
					'sanitize_callback' => 'sanitize_text_field',
					'label'             => esc_html__( 'Heading', 'real-home' ),
					'section'           => 'real_home_property_single_related_posts_section',
					'priority'          => 20,
				),
				// Enable/Disable
				'real_home_property_related_posts_enable' => array(
					'type'              => 'toggle',
					'default'           => array( 'desktop' => 'true' ),
					'section'           => 'real_home_property_single_related_posts_section',
					'priority'          => 20,
					'sanitize_callback' => array( 'Real_Home_Customizer_Sanitize_Callback', 'sanitize_toggle' ),
					'label'             => esc_html__( 'Related Posts', 'real-home' ),
				),

				// Number of posts
				'real_home_property_related_posts_limit'  => array(
					'type'              => 'range',
					'default'           => array( 'desktop' => 3 ),
					'sanitize_callback' => array( 'Real_Home_Customizer_Sanitize_Callback', 'sanitize_range' ),
					'label'             => esc_html__( 'No. of Posts', 'real-home' ),
					'section'           => 'real_home_property_single_related_posts_section',
					'priority'          => 25,
					'units'             => array(),
					'input_attrs'       => array(
						'min' => 0,
						'max' => 20,
					),
				),
				// Thumbnail Size
				'real_home_property_related_posts_featured_img_size' => array(
					'type'              => 'buttonset',
					'default'           => array( 'desktop' => 'medium' ),
					'sanitize_callback' => array( 'Real_Home_Customizer_Sanitize_Callback', 'sanitize_buttonset' ),
					'label'             => esc_html__( 'Image Size', 'real-home' ),
					'description'       => esc_html__( 'Set proper size for featured image. Selecting a bigger image size may display a better appearance but takes more time on loading websites.', 'real-home' ),
					'section'           => 'real_home_property_single_related_posts_section',
					'priority'          => 35,
					'choices'           => array(
						'thumbnail'    => esc_html__( 'Small', 'real-home' ),
						'medium'       => esc_html__( 'Medium', 'real-home' ),
						'medium_large' => esc_html__( 'Medium Large', 'real-home' ),
						'large'        => esc_html__( 'Large', 'real-home' ),
					),
				),
			)
		);
	}

}
new Real_Home_Customize_Property_Post_Fields();
