<?php
/**
 * Real Home Theme Customizer Front Page Advanced Search Sections settings
 *
 * @package Real_Home
 */

class Real_Home_Customize_Front_Page_Search_Fields extends Real_Home_Customize_Base_Field {

    /**
     * Arguments for fields.
     *
     * @return void
     */
    public function init() {

        if ( ! Real_Home_Helper::crucial_real_state_plugin() ) {
            $this->args = [
                // Information
                'real_home_front_page_search_plugin_notice' => [
                    'type'              => 'heading',
                    'sanitize_callback' => ['Real_Home_Customizer_Sanitize_Callback', 'sanitize_text' ],
                    'description'       => sprintf(
                        __( 'Real Home is compatible with <a href="%1$s" target="_blank"><strong>Crucial Real State</strong></a> plugin. Please active plugin to see settings.', 'real-home' ),
                        'https://wordpress.org/plugins/crucial-real-state/'
                    ),
                    'section'           => 'real_home_front_page_search_section',
                    'priority'          => 5,
                ]
            ];
            return;
        }

        $this->args = [
            // Grouping Settings
            'real_home_front_page_search_group_settings' => [
                'type'              => 'group',
                'section'           => 'real_home_front_page_search_section',
                'priority'          => 10,
                'choices'           => [
                    'normal'            => array(
                        'tab-title'     => esc_html__( 'General', 'real-home' ),
                        'controls'      => array(
                            'real_home_front_page_search_tabs'
                        )
                    ),
                    'hover'         => array(
                        'tab-title'     => esc_html__( 'Style', 'real-home' ),
                        'controls'      => array(
                            'real_home_front_page_search_note_one',
                            'real_home_front_page_search_background',
                            'real_home_front_page_search_background_overlay'
                        )
                    )
                ]
            ],
            // Separator One
            'real_home_front_page_search_note_one' => [
                'type'              => 'heading',
                'label'             => esc_html__( 'SECTION STYLING', 'real-home' ),
                'section'           => 'real_home_front_page_search_section',
                'priority'          => 15,
            ],
            // Background Image
            'real_home_front_page_search_background' => [
                'type'              => 'background',
                'default'           => '',
                'sanitize_callback' => ['Real_Home_Customizer_Sanitize_Callback', 'sanitize_background' ],
                'label'             => esc_html__( 'Background Image', 'real-home' ),
                'description'       => esc_html__( 'Set section container background image.', 'real-home' ),
                'section'           => 'real_home_front_page_search_section',
                'priority'          => 20,
                'fields'            => ['image' => true, 'position' => true, 'attachment' => true, 'repeat' => true, 'size' => true ],
            ],
            // Background Overlay
            'real_home_front_page_search_background_overlay' => [
                'type'              => 'background',
                'default'           => [
                    'background'        => 'color',
                    'colors'            => [
                        'color_1'           => 'var(--color-bg-4)'
                    ]
                ],
                'sanitize_callback' => ['Real_Home_Customizer_Sanitize_Callback', 'sanitize_background' ],
                'label'             => esc_html__( 'Background Overlay', 'real-home' ),
                'description'       => esc_html__( 'Set section container background overlay as color or gradient colors.', 'real-home' ),
                'section'           => 'real_home_front_page_search_section',
                'priority'          => 21,
                'inherits'          => [
                    'color_1'           => 'var(--color-bg-4)'
                ],
                'fields'            => ['colors' => true],
            ]
        ];
    }

}
new Real_Home_Customize_Front_Page_Search_Fields();